@@ -293,7 +293,7 @@ function event_loop!(
         else # event is ending, so remove it from the status
             idx = find_transition(sweep_status, head.other; atol=atol, rtol=rtol)
             if !(0 < idx <= length(sweep_status) && sweep_status[idx] === head.other)
-                @warn "$head was not in the expected location in the sweep status. " * 
+                @warn "$(head.other) was not in the expected location in the sweep status. " * 
                     "Falling back to linear search. This might result in incorrect annotations and hence open chains."
                 idx = findfirst(x -> x === head.other, sweep_status)
                 @assert(
@@ -322,7 +322,6 @@ function find_transition(
     searchsortedfirst(list, event; lt=(x, y) -> is_above(x, y; atol=atol, rtol=rtol))
 end
 
-
 """
     is_above(event, other, [atol, rtol])
 
@@ -334,11 +333,9 @@ Return `true` if `event` is strictly above `other`.
 A segment is considered above another if:
     1. It is to the left of the other segment.
     2. And the start point of the other segment is orientated clockwise from it.
-    3. Or the segment is a vertical line and the end point in the other segment is lower than its top.
 Or symmetrically:
-    1. It is to the right of the other segment.
-    2. And its start point segment is orientated counter-clockwise from the other segment.
-    3. Or the other segment is a vertical line and the end point of this segment is higher than that top.
+    1. It is in line or to the right of the other segment.
+    2. And its start point is orientated counter-clockwise from the other segment.
 
 Assumes segments always go left to right.
 """
@@ -348,19 +345,13 @@ function is_above(
     ) # statusCompare
     seg1 = ev.segment
     seg2 = other.segment
-    if (seg1[1][1] <= seg2[1][1])
-        if abs(seg1[2][1] - seg1[1][1]) <= atol # vertical segment
-            return seg2[2][2] < max(seg1[1][2], seg1[2][2]) # true if seg2 below seg1
-        end
+    if (seg1[1][1] < seg2[1][1])
         orient = get_orientation(seg1[1], seg1[2], seg2[1]; rtol=rtol, atol=atol)
         if orient == COLINEAR
             orient = get_orientation(seg1[1], seg1[2], seg2[2]; rtol=rtol, atol=atol)
         end
         return orient == CLOCKWISE
     else
-        if abs(seg2[2][1] - seg2[1][1]) <= atol # vertical segment
-            return seg1[2][2] > max(seg2[1][2], seg2[2][2]) # true if seg1 above seg2
-        end
         orient = get_orientation(seg2[1], seg2[2], seg1[1]; rtol=rtol, atol=atol)
         if orient == COLINEAR
             orient = get_orientation(seg2[1], seg2[2], seg1[2]; rtol=rtol, atol=atol)
