@@ -52,13 +52,11 @@ struct WeilerAthertonAlg <: PolygonIntersectionAlgorithm end
 - Returns regions and edges of interest. Does not return single points.
 - Works for convex and concave polygons including with holes and self-intersections.
 - Description: operates at a segment level and is an extension of the Bentley-Ottman line intersection algorithm.
-    Segments are scanned from left to right, bottom to top. 
-    The key assumption is that intersections are only found between the segments above and
-    below the current segment.
-    (This makes the algorithm fast but also sensitive to determining these segments correctly.)
-    In addition, the below segment (or empty space) is used to determine the fill annotations for 
-    the current segment.
-    Once the annotations are done, it is trivial to pick out segments that match the given criteria.
+    - Segments are scanned from left to right, bottom to top. 
+    - The key assumption is that only the segments immediately above and below the current segment need to be inspected for intersections.
+    This makes the algorithm fast but also sensitive to determining these segments correctly.
+    - The segment that is immediately below (or empty space) is used to determine the fill annotations for the current segment.
+    - Once all annotations are done, the desired segments can be selected that match a given criteria.
 - Limitations:
     1. It can fail for improper polygons: polygons with lines sticking out.
     2. It is sensitive to numeric inaccuracies e.g. a line that is almost vertical or 
